pub struct BacktestConfigInput {Show 32 fields
pub strategy_id: Option<i64>,
pub version_id: Option<i64>,
pub parameters: Option<Struct>,
pub venue_accounts: Option<Struct>,
pub start_date: Option<Timestamp>,
pub end_date: Option<Timestamp>,
pub benchmark: Option<String>,
pub commission_settings: Option<Struct>,
pub slippage_model: Option<Struct>,
pub config_name: Option<String>,
pub description: Option<String>,
pub tags: Vec<String>,
pub is_template: Option<bool>,
pub template_type: Option<String>,
pub is_public: Option<bool>,
pub creator_name: Option<String>,
pub enable_precompute: Option<bool>,
pub precompute_settings: Option<Struct>,
pub parent_config_id: Option<i64>,
pub created_by: Option<String>,
pub data_requirements: Vec<DataRequirement>,
pub oms_type: Option<String>,
pub reporting_currency: Option<String>,
pub debug_mode: Option<bool>,
pub graph_ir_schema_version: Option<String>,
pub graph_ir_hash: Option<String>,
pub graph_ir_uri: Option<String>,
pub node_catalog_version: Option<i64>,
pub node_catalog_checksum: Option<String>,
pub required_graph_runner_contract_version: Option<String>,
pub market_data_bindings: HashMap<String, MarketDataBinding>,
pub market_data_routes: Vec<MarketDataRoute>,
}Fields
strategy_id: Option<i64>version_id: Option<i64>parameters: Option<Struct>venue_accounts: Option<Struct>start_date: Option<Timestamp>end_date: Option<Timestamp>benchmark: Option<String>commission_settings: Option<Struct>slippage_model: Option<Struct>config_name: Option<String>description: Option<String>is_template: Option<bool>template_type: Option<String>is_public: Option<bool>creator_name: Option<String>enable_precompute: Option<bool>precompute_settings: Option<Struct>parent_config_id: Option<i64>created_by: Option<String>data_requirements: Vec<DataRequirement>oms_type: Option<String>reporting_currency: Option<String>debug_mode: Option<bool>graph_ir_schema_version: Option<String>graph_ir_hash: Option<String>graph_ir_uri: Option<String>node_catalog_version: Option<i64>node_catalog_checksum: Option<String>required_graph_runner_contract_version: Option<String>market_data_bindings: HashMap<String, MarketDataBinding>market_data_routes: Vec<MarketDataRoute>Implementations
Sourceimpl BacktestConfigInput
impl BacktestConfigInput
Sourcepub fn strategy_id(&self) -> i64
pub fn strategy_id(&self) -> i64
Returns the value of strategy_id, or the default value if strategy_id is unset.
Sourcepub fn version_id(&self) -> i64
pub fn version_id(&self) -> i64
Returns the value of version_id, or the default value if version_id is unset.
Sourcepub fn benchmark(&self) -> &str
pub fn benchmark(&self) -> &str
Returns the value of benchmark, or the default value if benchmark is unset.
Sourcepub fn config_name(&self) -> &str
pub fn config_name(&self) -> &str
Returns the value of config_name, or the default value if config_name is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn is_template(&self) -> bool
pub fn is_template(&self) -> bool
Returns the value of is_template, or the default value if is_template is unset.
Sourcepub fn template_type(&self) -> &str
pub fn template_type(&self) -> &str
Returns the value of template_type, or the default value if template_type is unset.
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns the value of is_public, or the default value if is_public is unset.
Sourcepub fn creator_name(&self) -> &str
pub fn creator_name(&self) -> &str
Returns the value of creator_name, or the default value if creator_name is unset.
Sourcepub fn enable_precompute(&self) -> bool
pub fn enable_precompute(&self) -> bool
Returns the value of enable_precompute, or the default value if enable_precompute is unset.
Sourcepub fn parent_config_id(&self) -> i64
pub fn parent_config_id(&self) -> i64
Returns the value of parent_config_id, or the default value if parent_config_id is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn oms_type(&self) -> &str
pub fn oms_type(&self) -> &str
Returns the value of oms_type, or the default value if oms_type is unset.
Sourcepub fn reporting_currency(&self) -> &str
pub fn reporting_currency(&self) -> &str
Returns the value of reporting_currency, or the default value if reporting_currency is unset.
Sourcepub fn debug_mode(&self) -> bool
pub fn debug_mode(&self) -> bool
Returns the value of debug_mode, or the default value if debug_mode is unset.
Sourcepub fn graph_ir_schema_version(&self) -> &str
pub fn graph_ir_schema_version(&self) -> &str
Returns the value of graph_ir_schema_version, or the default value if graph_ir_schema_version is unset.
Sourcepub fn graph_ir_hash(&self) -> &str
pub fn graph_ir_hash(&self) -> &str
Returns the value of graph_ir_hash, or the default value if graph_ir_hash is unset.
Sourcepub fn graph_ir_uri(&self) -> &str
pub fn graph_ir_uri(&self) -> &str
Returns the value of graph_ir_uri, or the default value if graph_ir_uri is unset.
Sourcepub fn node_catalog_version(&self) -> i64
pub fn node_catalog_version(&self) -> i64
Returns the value of node_catalog_version, or the default value if node_catalog_version is unset.
Sourcepub fn node_catalog_checksum(&self) -> &str
pub fn node_catalog_checksum(&self) -> &str
Returns the value of node_catalog_checksum, or the default value if node_catalog_checksum is unset.
Sourcepub fn required_graph_runner_contract_version(&self) -> &str
pub fn required_graph_runner_contract_version(&self) -> &str
Returns the value of required_graph_runner_contract_version, or the default value if required_graph_runner_contract_version is unset.