pub struct BacktestExecutionProgress {
pub phase: i32,
pub progress: f64,
pub simulation_time: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
phase: i32progress: f64simulation_time: Option<Timestamp>updated_at: Option<Timestamp>Implementations
Sourceimpl BacktestExecutionProgress
impl BacktestExecutionProgress
Sourcepub fn phase(&self) -> BacktestExecutionPhase
pub fn phase(&self) -> BacktestExecutionPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: BacktestExecutionPhase)
pub fn set_phase(&mut self, value: BacktestExecutionPhase)
Sets phase to the provided enum value.