pub struct GetResultReadinessResponse {
pub state: i32,
pub reason: Option<String>,
pub pending_components: Vec<String>,
}Fields
state: i32reason: Option<String>pending_components: Vec<String>Implementations
Sourceimpl GetResultReadinessResponse
impl GetResultReadinessResponse
Sourcepub fn state(&self) -> ResultReadinessState
pub fn state(&self) -> ResultReadinessState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ResultReadinessState)
pub fn set_state(&mut self, value: ResultReadinessState)
Sets state to the provided enum value.