pub struct GetRunnerLogsRequest {
pub backtest_id: String,
pub stream: Option<String>,
pub cursor: Option<i64>,
pub limit: Option<i32>,
pub page: Option<i32>,
pub page_size: Option<i32>,
pub level: Option<String>,
pub search: Option<String>,
}Fields
backtest_id: Stringstream: Option<String>cursor: Option<i64>limit: Option<i32>page: Option<i32>page_size: Option<i32>level: Option<String>search: Option<String>Implementations
Sourceimpl GetRunnerLogsRequest
impl GetRunnerLogsRequest
Sourcepub fn stream(&self) -> &str
pub fn stream(&self) -> &str
Returns the value of stream, or the default value if stream is unset.
Sourcepub fn cursor(&self) -> i64
pub fn cursor(&self) -> i64
Returns the value of cursor, or the default value if cursor is unset.
Sourcepub fn page_size(&self) -> i32
pub fn page_size(&self) -> i32
Returns the value of page_size, or the default value if page_size is unset.