pub struct GetRunnerLogsResponse {
pub execution_id: String,
pub execution_kind: String,
pub logs: Vec<RunnerLogItem>,
pub cursor: Option<RunnerLogsCursor>,
pub stats: Option<RunnerLogsStats>,
pub page: i32,
pub page_size: i32,
pub total: i64,
}Fields
execution_id: Stringexecution_kind: Stringlogs: Vec<RunnerLogItem>cursor: Option<RunnerLogsCursor>stats: Option<RunnerLogsStats>page: i32page_size: i32total: i64Trait Implementations
Sourceimpl Clone for GetRunnerLogsResponse
impl Clone for GetRunnerLogsResponse
Sourcefn clone(&self) -> GetRunnerLogsResponse
fn clone(&self) -> GetRunnerLogsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetRunnerLogsResponse
impl Debug for GetRunnerLogsResponse
Sourceimpl Default for GetRunnerLogsResponse
impl Default for GetRunnerLogsResponse
Sourceimpl Message for GetRunnerLogsResponse
impl Message for GetRunnerLogsResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetRunnerLogsResponse
impl PartialEq for GetRunnerLogsResponse
impl StructuralPartialEq for GetRunnerLogsResponse