pub struct GetTraceRequest {
pub backtest_id: String,
pub cursor: Option<i64>,
pub limit: Option<i32>,
pub node_id: Option<String>,
pub op_id: Option<String>,
pub status: Option<String>,
pub bar_time: Option<Timestamp>,
pub bar_type: Option<String>,
pub instrument_id: Option<String>,
pub target_cursor: Option<i64>,
pub event_scope: Option<String>,
}Fields
backtest_id: Stringcursor: Option<i64>limit: Option<i32>node_id: Option<String>op_id: Option<String>status: Option<String>bar_time: Option<Timestamp>bar_type: Option<String>instrument_id: Option<String>target_cursor: Option<i64>event_scope: Option<String>Implementations
Sourceimpl GetTraceRequest
impl GetTraceRequest
Sourcepub fn cursor(&self) -> i64
pub fn cursor(&self) -> i64
Returns the value of cursor, or the default value if cursor is unset.
Sourcepub fn node_id(&self) -> &str
pub fn node_id(&self) -> &str
Returns the value of node_id, or the default value if node_id is unset.
Sourcepub fn op_id(&self) -> &str
pub fn op_id(&self) -> &str
Returns the value of op_id, or the default value if op_id is unset.
Sourcepub fn status(&self) -> &str
pub fn status(&self) -> &str
Returns the value of status, or the default value if status is unset.
Sourcepub fn bar_type(&self) -> &str
pub fn bar_type(&self) -> &str
Returns the value of bar_type, or the default value if bar_type is unset.
Sourcepub fn instrument_id(&self) -> &str
pub fn instrument_id(&self) -> &str
Returns the value of instrument_id, or the default value if instrument_id is unset.
Sourcepub fn target_cursor(&self) -> i64
pub fn target_cursor(&self) -> i64
Returns the value of target_cursor, or the default value if target_cursor is unset.
Sourcepub fn event_scope(&self) -> &str
pub fn event_scope(&self) -> &str
Returns the value of event_scope, or the default value if event_scope is unset.