pub struct GetTraceResponse {
pub execution_id: String,
pub execution_kind: String,
pub artifacts: Option<NodeTraceArtifacts>,
pub events: Vec<NodeTraceEvent>,
pub cursor: Option<NodeTraceCursor>,
pub stats: Option<NodeTraceStats>,
pub value_facts: Vec<NodeTraceValueFact>,
}Fields
execution_id: Stringexecution_kind: Stringartifacts: Option<NodeTraceArtifacts>events: Vec<NodeTraceEvent>cursor: Option<NodeTraceCursor>stats: Option<NodeTraceStats>value_facts: Vec<NodeTraceValueFact>Trait Implementations
Sourceimpl Clone for GetTraceResponse
impl Clone for GetTraceResponse
Sourcefn clone(&self) -> GetTraceResponse
fn clone(&self) -> GetTraceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetTraceResponse
impl Debug for GetTraceResponse
Sourceimpl Default for GetTraceResponse
impl Default for GetTraceResponse
Sourceimpl Message for GetTraceResponse
impl Message for GetTraceResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetTraceResponse
impl PartialEq for GetTraceResponse
impl StructuralPartialEq for GetTraceResponse