pub struct ListConfigsRequest {
pub is_template: Option<String>,
pub template_type: Option<String>,
pub is_public: Option<String>,
pub visibility: Option<String>,
pub created_by: Option<String>,
pub keyword: Option<String>,
pub tags: Vec<String>,
pub sort_by: Option<String>,
pub sort_order: Option<String>,
pub page: Option<i32>,
pub page_size: Option<i32>,
}Fields
is_template: Option<String>template_type: Option<String>is_public: Option<String>visibility: Option<String>created_by: Option<String>keyword: Option<String>sort_by: Option<String>sort_order: Option<String>page: Option<i32>page_size: Option<i32>Implementations
Sourceimpl ListConfigsRequest
impl ListConfigsRequest
Sourcepub fn is_template(&self) -> &str
pub fn is_template(&self) -> &str
Returns the value of is_template, or the default value if is_template is unset.
Sourcepub fn template_type(&self) -> &str
pub fn template_type(&self) -> &str
Returns the value of template_type, or the default value if template_type is unset.
Sourcepub fn is_public(&self) -> &str
pub fn is_public(&self) -> &str
Returns the value of is_public, or the default value if is_public is unset.
Sourcepub fn visibility(&self) -> &str
pub fn visibility(&self) -> &str
Returns the value of visibility, or the default value if visibility is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn keyword(&self) -> &str
pub fn keyword(&self) -> &str
Returns the value of keyword, or the default value if keyword is unset.
Sourcepub fn sort_by(&self) -> &str
pub fn sort_by(&self) -> &str
Returns the value of sort_by, or the default value if sort_by is unset.
Sourcepub fn sort_order(&self) -> &str
pub fn sort_order(&self) -> &str
Returns the value of sort_order, or the default value if sort_order is unset.