pub struct NodeTraceEvent {Show 15 fields
pub cursor: i64,
pub runtime_sequence: i64,
pub op_id: String,
pub node_id: String,
pub node_type: String,
pub lifecycle: String,
pub event_kind: String,
pub status: String,
pub branch: Option<String>,
pub reason: Option<String>,
pub error: Option<Struct>,
pub event_at: Option<Timestamp>,
pub bar_time: Option<Timestamp>,
pub bar_type: Option<String>,
pub instrument_id: Option<String>,
}Fields
cursor: i64runtime_sequence: i64op_id: Stringnode_id: Stringnode_type: Stringlifecycle: Stringevent_kind: Stringstatus: Stringbranch: Option<String>reason: Option<String>error: Option<Struct>event_at: Option<Timestamp>bar_time: Option<Timestamp>bar_type: Option<String>instrument_id: Option<String>Implementations
Sourceimpl NodeTraceEvent
impl NodeTraceEvent
Sourcepub fn branch(&self) -> &str
pub fn branch(&self) -> &str
Returns the value of branch, or the default value if branch is unset.
Sourcepub fn reason(&self) -> &str
pub fn reason(&self) -> &str
Returns the value of reason, or the default value if reason is unset.
Sourcepub fn bar_type(&self) -> &str
pub fn bar_type(&self) -> &str
Returns the value of bar_type, or the default value if bar_type is unset.
Sourcepub fn instrument_id(&self) -> &str
pub fn instrument_id(&self) -> &str
Returns the value of instrument_id, or the default value if instrument_id is unset.