pub struct ComparisonViewportGrid {
pub grid_version: String,
pub source_frequency: String,
pub requested_view_start_time: Option<Timestamp>,
pub requested_view_end_time: Option<Timestamp>,
pub viewport_width_px: i32,
pub bucket_size_bars: i64,
pub source_point_count: i64,
pub view_source_point_count: i64,
pub returned_bucket_count: i64,
}Expand description
Metadata for the deterministic, UTC-anchored comparison_grid_v1 contract.
Implementations clamp viewport_width_px to 64..8192 and then round it up to a 128px step. They calculate the number of canonical source-frequency slots intersecting the half-open requested viewport, divide that count by the normalized width, and round the result up to the next positive power of two. That value is bucket_size_bars. Bucket zero is anchored at the Unix epoch; display_time is the canonical timestamp of the final source Bar slot in the bucket. See comparison_grid_v1_test_vectors.json for conformance cases.
Fields
grid_version: Stringsource_frequency: Stringrequested_view_start_time: Option<Timestamp>requested_view_end_time: Option<Timestamp>viewport_width_px: i32bucket_size_bars: i64source_point_count: i64view_source_point_count: i64returned_bucket_count: i64Trait Implementations
Sourceimpl Clone for ComparisonViewportGrid
impl Clone for ComparisonViewportGrid
Sourcefn clone(&self) -> ComparisonViewportGrid
fn clone(&self) -> ComparisonViewportGrid
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComparisonViewportGrid
impl Debug for ComparisonViewportGrid
Sourceimpl Default for ComparisonViewportGrid
impl Default for ComparisonViewportGrid
Sourceimpl Message for ComparisonViewportGrid
impl Message for ComparisonViewportGrid
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ComparisonViewportGrid
impl PartialEq for ComparisonViewportGrid
impl StructuralPartialEq for ComparisonViewportGrid